//-----------------------------------------------------------------------------
// drawer.m
//
// Example of a simple drawer
//
// created by FrisbeeMonkey
//-----------------------------------------------------------------------------

//                            USING THIS SCRIPT:
//*****************************************************************************
//  1.  Define a drawer group in your XML.
//  2.  Add your background layer to the group, something like:
//        <layer id="Drawer" image="player.Drawer" x="0" y="0" sysregion="1"/>
//        You can change any of the values but the id and sysregion
//  3.  Add a layer to pass info to this script, something like:
//        <layer id="DrawerInfo" x="13" y="0"/>
//        Set x and y to where you want your drawer to slide to
//  3.  Add any other objects(layers, buttons, sliders, etc) to your group
//  4.  Copy this script (and drawer.maki) to your scripts folder.
//  5.  If you don't have drawer.maki, compile this script.
//  6.  Add this line to the group that you want to be a drawer:
//        <script id="drawer" file="scripts/drawer.maki"/>
//  7.  Refresh your skin(F5) and try it out.
//*****************************************************************************

//                               EXAMPLE XML
//=============================================================================
//<groupdef id="DrawerGroup" w="39" h="158"> <!-- 39,0 -->
//
//  <layer id="Drawer" image="player.Drawer" x="0" y="0" sysregion="1" move="0"/>
//  <layer id="DrawerInfo" x="13" y="0"/>
//  //add other objects that you want to move with the drawer here
//
//  <script id="drawer" file="scripts/drawer.maki"/>
//</groupdef>
//=============================================================================
//  ***Don't forget to place your group somewhere in your layout!***
//  <group id="DrawerGroup" x="47" y="0"/>


// never forget to include std.mi
#include "lib/std.mi"


//declares global variables for use in script
Global Group DrawerGrp;
Global Layer DrawerInfoL, DrawerInfoR, DrawerL, DrawerR;
Global Button CThemeButt;
Global Group DrawerGrpL, DrawerGrpR, CThemes;
Global Int DrawerStatus;  //0 = closed, 1 = open
Global Int LStartX, LStartY, LEndX, LEndY, RStartX, RStartY, REndX, REndY;
Global Timer ColorTimer;

//when the script is loaded, do this
System.onScriptLoaded() {

	//gets the group that has the objects we want
	DrawerGrp = getScriptGroup();
	
	//Color THemes List Group
	CThemes = DrawerGrp.findObject("ColorThemesGroup");

	//BUtton for Open Drawer
	CThemeButt = DrawerGrp.findObject("cthemebutton");

	// Initialize our timer
	ColorTimer = new Timer;
	ColorTimer.setDelay(200);

	//now that we have the group, get the layers in the group
	DrawerGrpL = DrawerGrp.findObject("DrawerGroupL");
	DrawerL = DrawerGrpL.findObject("DrawerL");
	DrawerInfoL = DrawerGrpL.findObject("DrawerInfoL");

	DrawerGrpR = DrawerGrp.findObject("DrawerGroupR");
	DrawerR = DrawerGrpR.findObject("DrawerR");
	DrawerInfoR = DrawerGrpR.findObject("DrawerInfoR");

	LStartX = StringToInteger(DrawerGrpL.getXMLparam("x"));
	LStartY = StringToInteger(DrawerGrpL.getXMLparam("y"));
	LEndX = StringToInteger(DrawerInfoL.getXMLparam("x"));
	LEndY = StringToInteger(DrawerInfoL.getXMLparam("y"));

	RStartX = StringToInteger(DrawerGrpR.getXMLparam("x"));
	RStartY = StringToInteger(DrawerGrpR.getXMLparam("y"));
	REndX = StringToInteger(DrawerInfoR.getXMLparam("x"));
	REndY = StringToInteger(DrawerInfoR.getXMLparam("y"));

	//initialize our drawer flag to closed
	DrawerStatus = 0;

}

ColorTimer.onTimer() {
	if (!DrawerGrpL.isGoingToTarget() && !DrawerGrpR.isGoingToTarget()) {  //makes sure it isn't already moving
		if (DrawerStatus == 1) {
			CThemes.setXMLparam("visible","1");
		}
		ColorTimer.stop();
	}
}

//when the left mouse button is released within Drawer, do this
CThemeButt.onLeftButtonUp(int x, int y) {
  if (DrawerStatus == 0) {  // if our Drawer is closed, make it slide open
    if (!DrawerGrpL.isGoingToTarget() && !DrawerGrpR.isGoingToTarget()) {  //makes sure it isn't already moving
      ColorTimer.start();
      DrawerGrpL.setTargetX(LEndX);
      DrawerGrpL.setTargetY(LEndY);
      DrawerGrpL.setTargetSpeed(1);
      DrawerGrpL.gotoTarget();
      DrawerGrpR.setTargetX(REndX);
      DrawerGrpR.setTargetY(REndY);
      DrawerGrpR.setTargetSpeed(1);
      DrawerGrpR.gotoTarget();
      DrawerStatus = 1;  //Change the flag to Open
    }
  }
  else {  // if our Drawer is open, make it slide closed
    if (!DrawerGrpL.isGoingToTarget() && !DrawerGrpR.isGoingToTarget()) {  //makes sure it isn't already moving
      CThemes.setXMLparam("visible","0");
      DrawerGrpL.setTargetX(LStartX);
      DrawerGrpL.setTargetY(LStartY);
      DrawerGrpL.setTargetSpeed(1);
      DrawerGrpL.gotoTarget();
      DrawerGrpR.setTargetX(RStartX);
      DrawerGrpR.setTargetY(RStartY);
      DrawerGrpR.setTargetSpeed(1);
      DrawerGrpR.gotoTarget();
      DrawerStatus = 0;  //Change the flag to Closed
    }
  }
}